@@ -11,7 +11,7 @@ import requests
 from conftest import skip_gitlab_ci
 from unittest.mock import Mock, patch
 
-from ae.base import PY_CACHE_FOLDER, PY_INIT, norm_name
+from ae.base import PY_CACHE_FOLDER, PY_INIT, load_dotenvs, norm_name
 from aedev.pythonanywhere import PythonanywhereApi
 
 
@@ -54,8 +54,7 @@ def connection():
     """ provide personal pythonanywhere remote web server for tests only running locally with personal credentials. """
     web_domain = "www.pythonanywhere.com"
     web_user = "AndiEcker"
-    from dotenv import load_dotenv
-    load_dotenv()
+    load_dotenvs()
     web_token = os.environ.get(f'AE_OPTIONS_WEB_TOKEN_AT_{norm_name(web_domain).upper()}')
 
     remote_connection = PythonanywhereApi(web_domain, web_user, web_token, TEST_PROJECT_NAME)
